@@ -52,11 +52,11 @@ package com.openexchange.printing.email;
 
 import java.util.Map;
 import java.util.TimeZone;
-
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.ajax.requesthandler.Converter;
 import com.openexchange.exception.OXException;
+import com.openexchange.groupware.ldap.User;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.templating.TemplateHelperFactory;
 import com.openexchange.tools.session.ServerSession;
@@ -64,20 +64,20 @@ import com.openexchange.tools.session.ServerSession;
 public class EmailTemplateHelperFactory implements TemplateHelperFactory {
 
 	private final ServiceLookup services;
-	
+
     public EmailTemplateHelperFactory(ServiceLookup services) {
         this.services = services;
     }
-    
+
 	@Override
 	public String getName() {
 		return "email";
 	}
 
 	@Override
-	public Object create(AJAXRequestData requestData, AJAXRequestResult result, ServerSession session, Converter converter, Map<String, Object> rootObject) throws OXException {			
-
-		TimeZone tz = TimeZone.getTimeZone( requestData.isSet("timezone") ? requestData.getParameter("timezone") : session.getUser().getTimeZone() );			    
-		return new EmailHelper((Map<String, Object>) result.getResultObject(), session.getUser().getLocale(), tz, session.getContext(), services);
+	public Object create(AJAXRequestData requestData, AJAXRequestResult result, ServerSession session, Converter converter, Map<String, Object> rootObject) throws OXException {
+		User user = session.getUser();
+        TimeZone tz = TimeZone.getTimeZone( requestData.isSet("timezone") ? requestData.getParameter("timezone") : user.getTimeZone() );
+		return new EmailHelper((Map<String, Object>) result.getResultObject(), user.getLocale(), tz, session.getContext(), services);
 	}
 }
\ No newline at end of file
